@@ -40,6 +40,16 @@ final class ClosureComparator extends Comparator
         $expectedReflector = new ReflectionFunction($expected);
         $actualReflector   = new ReflectionFunction($actual);
 
+        $expectedFilename  = $expectedReflector->getFileName();
+        $expectedStartLine = $expectedReflector->getStartLine();
+        $actualFilename    = $actualReflector->getFileName();
+        $actualStartLine   = $actualReflector->getStartLine();
+
+        assert($expectedFilename !== false);
+        assert($expectedStartLine !== false);
+        assert($actualFilename !== false);
+        assert($actualStartLine !== false);
+
         throw new ComparisonFailure(
             $expected,
             $actual,
@@ -47,10 +57,10 @@ final class ClosureComparator extends Comparator
             'Closure Object #' . spl_object_id($actual) . ' ()',
             sprintf(
                 'Failed asserting that closure declared at %s:%d is equal to closure declared at %s:%d.',
-                $expectedReflector->getFileName(),
-                $expectedReflector->getStartLine(),
-                $actualReflector->getFileName(),
-                $actualReflector->getStartLine(),
+                $expectedFilename,
+                $expectedStartLine,
+                $actualFilename,
+                $actualStartLine,
             ),
         );
     }
