@@ -12,10 +12,11 @@ namespace SebastianBergmann\Comparator;
 use PHPUnit\Framework\Attributes\CoversClass;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\Attributes\UsesClass;
+use PHPUnit\Framework\Attributes\UsesClassesThatExtendClass;
 use PHPUnit\Framework\TestCase;
 
 #[CoversClass(ComparisonFailure::class)]
-#[UsesClass(Comparator::class)]
+#[UsesClassesThatExtendClass(Comparator::class)]
 #[UsesClass(Factory::class)]
 #[Small]
 final class ComparisonFailureTest extends TestCase
