@@ -13,12 +13,13 @@ use PHPUnit\Framework\Attributes\CoversClass;
 use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\Attributes\UsesClass;
+use PHPUnit\Framework\Attributes\UsesClassesThatExtendClass;
 use PHPUnit\Framework\TestCase;
 use SplObjectStorage;
 use stdClass;
 
 #[CoversClass(SplObjectStorageComparator::class)]
-#[UsesClass(Comparator::class)]
+#[UsesClassesThatExtendClass(Comparator::class)]
 #[UsesClass(ComparisonFailure::class)]
 #[UsesClass(Factory::class)]
 #[Small]
